version = '1.10.2'
version_cmd = 'nginx -v'
depends = ['build-essential', 'libpcre3-dev', 'zlib1g-dev', 'libssl-dev']
download_url = 'http://nginx.org/download/nginx-VERSION.tar.gz'
install_script = """
tar -xzf nginx-VERSION.tar.gz
cd nginx-VERSION/
./configure \
    --with-http_ssl_module \
    --with-http_auth_request_module \
    --prefix=/etc/nginx \
    --conf-path=/etc/nginx/nginx.conf \
    --sbin-path=/usr/sbin/nginx \
    --pid-path=/var/run/nginx.pid \
    --error-log-path=/var/log/nginx/error.log \
    --http-log-path=/var/log/nginx/access.log
make
make install

mkdir -p /etc/nginx/sites-enabled
chmod -R 0700 /etc/nginx
"""



version = '3.2.5'
version_cmd = 'redis-server -v'
depends = ['build-essential']
download_url = 'http://download.redis.io/releases/redis-VERSION.tar.gz'
install_script = """
tar -xzf redis-VERSION.tar.gz
cd redis-VERSION/
make
make install
"""



version = '5.1.8'
version_cmd = 'VBoxManage -v'
depends=['dkms', 'libgl1-mesa-glx', 'libqt4-network', 'libqt4-opengl', 'libqtcore4', 'libqtgui4', 'libsdl1.2debian', 'libvpx1', 'libxcursor1', 'libxinerama1']
download_url = 'http://download.virtualbox.org/virtualbox/5.1.8/virtualbox-5.1_5.1.8-111374~Ubuntu~xenial_amd64.deb'
install_script = """
# Installation may fail because of missing dependencies, but we can resolve this afterward.
dpkg -i virtualbox-5.1_5.1.8-111374~Ubuntu~xenial_amd64.deb || true
apt-get install -fy
"""



version = '2.3.1'
version_cmd = 'elasticsearch -version'
download_url = 'http://packages.elasticsearch.org/GPG-KEY-elasticsearch'
install_script = """
apt-key add GPG-KEY-elasticsearch
echo "deb http://packages.elasticsearch.org/elasticsearch/VERSION/debian stable main" > /etc/apt/sources.list.d/elasticsearch.list
apt-get update -qq
apt-get install -y elasticsearch
service elasticsearch start
"""



version = '0.6.2'
version_cmd = 'vault -v'
depends = ['unzip']
download_url = 'https://releases.hashicorp.com/vault/VERSION/vault_VERSION_linux_amd64.zip'
install_script = """
unzip -o vault_VERSION_linux_amd64.zip
mv -f vault /usr/local/bin/vault
"""



version = '2.3.5'
version_cmd = 'rethinkdb -v'
depends = ['apt-transport-https']
install_script = """
echo deb https://download.rethinkdb.com/apt `lsb_release -c | awk '{print $2}'` main > /etc/apt/sources.list.d/rethinkdb.list
wget -qO- https://download.rethinkdb.com/apt/pubkey.gpg | apt-key add -
apt-get update -o Dir::Etc::sourcelist="sources.list.d/rethinkdb.list" -o Dir::Etc::sourceparts="-" -o APT::Get::List-Cleanup="0"
apt-get install -y rethinkdb
"""



version = '0.7.0'
version_cmd = 'consul -v'
depends = ['unzip']
download_url = 'https://releases.hashicorp.com/consul/VERSION/consul_VERSION_linux_amd64.zip'
install_script = """
unzip -o consul_VERSION_linux_amd64.zip
mv -f consul /usr/local/bin/consul
"""



name = 'mongodb'
version = '3.2.10'
version_cmd = 'mongod --version'
install_script = '''
apt-key adv --keyserver hkp://keyserver.ubuntu.com:80 --recv 7F0CEB10
echo 'deb http://downloads-distro.mongodb.org/repo/ubuntu-upstart dist 10gen' > /etc/apt/sources.list.d/mongodb.list
apt-get update -qq
apt-get install -qy mongodb-org
'''



version = '1.12.3'
version_cmd = 'docker -v'
depends = ['apt-transport-https']
install_script = """
echo deb https://apt.dockerproject.org/repo ubuntu-`lsb_release -c | awk '{print $2}'` main > /etc/apt/sources.list.d/docker.list
apt-key adv --keyserver hkp://p80.pool.sks-keyservers.net:80 --recv-keys 58118E89F3A912897C070ADBF76221572C52609D
apt-get update -o Dir::Etc::sourcelist="sources.list.d/docker.list" -o Dir::Etc::sourceparts="-" -o APT::Get::List-Cleanup="0"
apt-get install -y docker-engine
"""



version = '1.7.1'
version_cmd = 'go version'
version_re = 'go version go([\d\.]+)'
download_url = 'https://storage.googleapis.com/golang/goVERSION.linux-amd64.tar.gz'
install_script = """
rm -rf /usr/local/go
tar -C /usr/local -xzf goVERSION.linux-amd64.tar.gz
echo "export PATH=\$PATH:/usr/local/go/bin" > /etc/profile.d/golang.sh
grep "/usr/local/go/bin" /etc/bash.bashrc >/dev/null || echo "export PATH=\$PATH:/usr/local/go/bin" >> /etc/bash.bashrc
"""



version = '0.16.0'
version_cmd = 'consul-template -v'
depends = ['unzip']
download_url = 'https://releases.hashicorp.com/consul-template/VERSION/consul-template_VERSION_linux_amd64.zip'
install_script = """
unzip -o consul-template_VERSION_linux_amd64.zip
mv -f consul-template /usr/local/bin/consul-template
"""



version = '2.7.12'
version_cmd = 'python -v'
# depends=['build-essential', 'libpcre3-dev', 'zlib1g-dev', 'libssl-dev']
download_url = 'https://www.python.org/ftp/python/VERSION/Python-VERSION.tgz'
install_script = """
tar -xzf Python-VERSION.tgz
cd Python-VERSION/
./configure
make
make altinstall
"""



version = '0.2.1'
version_cmd = 'hostess -v'
version_re = 'hostess version (\d+\.\d+\.\d+)'
download_url = 'https://github.com/cbednarski/hostess/releases/download/vVERSION/hostess_linux_amd64'
install_script = """
  chmod +x hostess
  mv hostess /usr/local/bin/hostess
"""



version = '6.9.1'
version_cmd = 'node -v'
download_url = 'http://nodejs.org/dist/vVERSION/node-vVERSION-linux-x64.tar.gz'
install_script = """
  tar --strip-components 1 -C /usr/local -xzf node-vVERSION-linux-x64.tar.gz
"""



version = '0.11.0'
version_cmd = 'confd -version'
download_url = 'https://github.com/kelseyhightower/confd/releases/download/vVERSION/confd-VERSION-linux-amd64'
install_script = """
chmod +x confd-VERSION-linux-amd64
mv -f confd-VERSION-linux-amd64 /usr/local/bin/confd
"""



version = '0.6.1'
version_cmd = 'envconsul -v'
depends = ['unzip']
download_url = 'https://releases.hashicorp.com/envconsul/VERSION/envconsul_VERSION_linux_amd64.zip'
install_script = """
unzip -o envconsul_VERSION_linux_amd64.zip
mv -f envconsul /usr/local/bin/envconsul
"""



version = '1.6.9'
version_cmd = 'haproxy -v'
depends = ['build-essential', 'libpcre3-dev', 'zlib1g-dev', 'libssl-dev']
download_url = 'http://www.haproxy.org/download/1.6/src/haproxy-VERSION.tar.gz'

upstart = """
start on runlevel [2345]
stop on runlevel [016]

expect fork

pre-start exec haproxy -t
pre-stop exec haproxy -s quit

reload signal SIGHUP

exec haproxy
"""

install_script = """
echo "This installer is broken :("
echo "Please help fix it: https://github.com/cbednarski/ifs/issues/9"
# tar -xzf haproxy-VERSION.tar.gz
# cd haproxy-VERSION
# make TARGET=generic USE_TFO=1 USE_PCRE=1 USE_STATIC_PCRE=1 USE_PCRE_JIT=1 USE_OPENSSL=1
# make install
# if [ ! -d /etc/haproxy ] ; then mkdir -p /etc/haproxy ; fi
# cp examples/haproxy.cfg /etc/haproxy/haproxy.cfg
# haproxy -v
exit 1
"""



version = '0.7.9'
version_cmd = 'terraform version'
version_re = 'Terraform v(\d+\.\d+\.\d+).*'
depends = ['unzip']
download_url = 'https://releases.hashicorp.com/terraform/VERSION/terraform_VERSION_linux_amd64.zip'
install_script = """
  unzip -o terraform_VERSION_linux_amd64.zip
  chmod +x terraform*
  mv terraform* /usr/local/bin/
"""



version_cmd = 'java -jar /usr/share/jenkins/jenkins.war --version'
version_re = '(\d\.\d{3})'
depends = ['wget']
install_script = """
wget -q -O - http://pkg.jenkins-ci.org/debian/jenkins-ci.org.key | apt-key add -
echo "deb http://pkg.jenkins-ci.org/debian binary/" > /etc/apt/sources.list.d/jenkins.list
apt-get update -o Dir::Etc::sourcelist="sources.list.d/jenkins.list" -o Dir::Etc::sourceparts="-" -o APT::Get::List-Cleanup="0"
apt-get install -y jenkins
"""



version = '1.8.0_112'
version_cmd = 'java -version'
version_re = 'java version "(\d+\.\d+\.\d+_\d+)"'
description = "Oracle Java 8"
install_script = """
wget -nv --header "Cookie: oraclelicense=accept-securebackup-cookie" -O jdk-8u112-linux-x64.tar.gz http://download.oracle.com/otn-pub/java/jdk/8u112-b15/jdk-8u112-linux-x64.tar.gz
rm -rf jdk1.8.0_112/
tar -xzf jdk-8u112-linux-x64.tar.gz
rm -rf /opt/jdk1.8.0_112
mv jdk1.8.0_112/ /opt
echo "export JAVA_HOME=/opt/jdk1.8.0_112\nexport PATH=\$PATH:\$JAVA_HOME/bin" > /etc/profile.d/oracle-java8.sh
grep "/opt/jdk1.8.0_112" /etc/bash.bashrc >/dev/null || echo "export JAVA_HOME=/opt/jdk1.8.0_112\nexport PATH=\$PATH:\$JAVA_HOME/bin" >> /etc/bash.bashrc
"""



version = '2.1.4'
version_cmd = 'riak version'
download_url = 'http://s3.amazonaws.com/downloads.basho.com/riak/2.1/2.1.1/ubuntu/trusty/riak_2.1.1-1_amd64.deb'
install_script = """
dpkg -i riak_2.1.1-1_amd64.deb
"""



from setuptools import setup

setup(
    name='ifs',
    version='0.12.0',
    author='Chris Bednarski',
    author_email='banzaimonkey@gmail.com',
    url='https://github.com/cbednarski/ifs',
    description='Install from source',
    license='ISC',
    packages=['ifs', 'ifs.source'],
    include_package_data=True,
    install_requires=[
        'Click',
        'colorama'
    ],
    entry_points='''
        [console_scripts]
        ifs=ifs.cli:cli
    '''
)



version = '0.11.0'
version_cmd = 'packer version'
version_re = 'Packer v(\d+\.\d+\.\d+).*'
depends = ['unzip']
download_url = 'https://releases.hashicorp.com/packer/VERSION/packer_VERSION_linux_amd64.zip'
install_script = """
  unzip -o packer_VERSION_linux_amd64.zip
  chmod +x packer
  mv packer /usr/local/bin/packer
"""



version = '0.4.1'
version_cmd = 'nomad -v'
depends = ['unzip']
download_url = 'https://releases.hashicorp.com/nomad/VERSION/nomad_VERSION_linux_amd64.zip'
install_script = """
unzip -o nomad_VERSION_linux_amd64.zip
mv -f nomad /usr/local/bin/nomad
"""
